require "test_helper"

class ManagedClassesTest < ActiveSupport::TestCase

  test "can manage, check, and unmanage a model" do

    class ::Card < ActiveRecord::Base
      manage_with_tolaria using:{
        navigation_label: "Widgets",
        icon: "credit-card",
        priority: 5,
        category: "Payments",
        default_order: "id DESC",
        paginated: true,
        allowed_actions: [:index, :show]
      }
    end

    # Find that class
    managed_class = Tolaria.managed_classes.find do |managed_class|
      managed_class.klass.eql?(Card)
    end

    # Did we find the class we just managed?
    assert managed_class.present?
    assert managed_class.klass.eql?(Card)

    # Can we can get our settings back?
    assert_equal managed_class.icon, "credit-card"
    assert_equal managed_class.priority, 5
    assert_equal managed_class.category, "Payments"
    assert_equal managed_class.default_order, "id DESC"
    assert_equal managed_class.allowed_actions, [:index, :show]
    assert managed_class.paginated, true

    # Can we override the navigation label?
    assert_equal managed_class.navigation_label, "Widgets"

    # Can we check action allowances?
    assert managed_class.allows?(:index), "should allow `index` action"
    assert managed_class.allows?(:show), "should allow `show` action"
    refute managed_class.allows?(:edit), "shouldn't allow `edit` action"
    refute managed_class.allows?(:discard), "shouldn't allow nonsense action"

    # Are our autogenerated name are correct?
    assert_equal managed_class.controller_name, "CardsController"
    assert_equal managed_class.param_key, :card

    # Can we throw away our work?
    assert Tolaria.discard_managed_class(Card), "should unseat Card class"
    assert Tolaria.managed_classes.collect(&:klass).exclude?(Card), "shouldn't have card class"

    # Unseat the Card class so that it doesn't leak out of this test
    Object.send(:remove_const, :Card)

  end

end
